From 0700c443d9162ac4928ac8fee58278c1f0824736 Mon Sep 17 00:00:00 2001
From: Pavel Shlyak <p.shlyak@pantherx.org>
Date: Thu, 26 May 2022 21:00:51 +0300
Subject: [PATCH] Image API: support FAT32 partitions

---
 gnu/build/image.scm  | 8 +++++---
 gnu/system/image.scm | 2 ++
 2 files changed, 7 insertions(+), 3 deletions(-)

diff --git a/gnu/build/image.scm b/gnu/build/image.scm
index 3e8b94e2d6..804685c7fb 100644
--- a/gnu/build/image.scm
+++ b/gnu/build/image.scm
@@ -95,12 +95,12 @@ (define* (make-ext-image partition target root
                            (estimate-partition-size root)
                            size)))))))
 
-(define* (make-vfat-image partition target root)
+(define* (make-vfat-image partition target root fs_bits)
   "Handle the creation of VFAT partition images.  See 'make-partition-image'."
   (let ((size (partition-size partition))
         (label (partition-label partition)))
     (invoke "fakeroot" "mkdosfs" "-n" label "-C" target
-            "-F" "16" "-S" "1024"
+            "-F" fs_bits "-S" "1024"
             (size-in-kib
              (if (eq? size 'guess)
                  (estimate-partition-size root)
@@ -121,7 +121,9 @@ (define* (make-partition-image partition-sexp target root)
      ((string-prefix? "ext" type)
       (make-ext-image partition target root))
      ((string=? type "vfat")
-      (make-vfat-image partition target root))
+      (make-vfat-image partition target root "16"))
+     ((string=? type "fat32")
+      (make-vfat-image partition target root "32"))
      (else
       (raise (condition
               (&message
diff --git a/gnu/system/image.scm b/gnu/system/image.scm
index dd32e58c2d..0dd16ed34e 100644
--- a/gnu/system/image.scm
+++ b/gnu/system/image.scm
@@ -313,6 +313,7 @@ (define (partition->dos-type partition)
          ((member 'esp flags) "0xEF")
          ((string-prefix? "ext" file-system) "0x83")
          ((string=? file-system "vfat") "0x0E")
+         ((string=? file-system "fat32") "0x0C")
          (else
           (raise (condition
                   (&message
@@ -330,6 +331,7 @@ (define (partition->gpt-type partition)
          ((member 'esp flags) "U")
          ((string-prefix? "ext" file-system) "L")
          ((string=? file-system "vfat") "F")
+         ((string=? file-system "fat32") "F")
          (else
           (raise (condition
                   (&message
-- 
2.32.1 (Apple Git-133)

